import JWT from "../../JWT.ts";
import Router, { makeParameterModifier } from "../Router.ts";

export type AuthType = 'raw' | 'jwt';

export function auth<T extends Router>(salt: (self: T) => string, type: AuthType = 'jwt') {
    return makeParameterModifier<T>(function (req) {
        let res = req.headers.authorization;
        if (typeof res !== 'string') return undefined;
        if (res.startsWith('Bearer')) res = res.substring(6).trimStart();

        if (type === 'jwt') return JWT.decode(res, salt(this));

        return res;
    });
}