import HttpError from "../HttpError.ts";
import { makeParameterModifier } from "../Router.ts";

export type BodyType = 'raw' | 'json';

export default function body(type: BodyType = 'json') {
    return makeParameterModifier(async req => {
        let body = req.body;
        if (type === 'json') {
            try {
                if (body instanceof Blob) body = await body.text();
                if (typeof body === 'string') body = JSON.parse(body.toString());
            }
            catch (e) {
                if (e instanceof SyntaxError) throw new HttpError('Body syntax error: ' + e.message);
            }
        }
        return body;
    });
}